@@ -1,27 +1,16 @@
-/*  This file is part of the KDE libraries
- *  Copyright (C) 1999 David Faure <faure@kde.org>
- *  Copyright (C) 2000 Waldo Bastian <bastian@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License version 2 as published by the Free Software Foundation;
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- **/
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2000 Waldo Bastian <bastian@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #include "kded.h"
 #include "kdedadaptor.h"
 #include "kded_version.h"
 
-#include <kcrash.h>
+#include <KCrash>
 
 #include <qplatformdefs.h>
 
@@ -30,17 +19,17 @@
 #include <QTimer>
 #include <QCommandLineParser>
 #include <QApplication>
+#include <QProcess>
 
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 #include <QDBusServiceWatcher>
 
 #include <KDBusService>
-#include <kconfiggroup.h>
-#include <ksharedconfig.h>
+#include <KConfigGroup>
+#include <KSharedConfig>
 #include <KDirWatch>
 #include <KServiceTypeTrader>
-#include <KToolInvocation>
 #include <KPluginInfo>
 #include <KPluginMetaData>
 
@@ -50,7 +39,7 @@
 
 Q_DECLARE_LOGGING_CATEGORY(KDED)
 
-Q_LOGGING_CATEGORY(KDED, "kf5.kded", QtWarningMsg)
+Q_LOGGING_CATEGORY(KDED, "kf.kded", QtWarningMsg)
 
 Kded *Kded::_self = nullptr;
 
@@ -66,8 +55,9 @@ extern QDBUS_EXPORT void qDBusAddSpyHook(void (*)(const QDBusMessage &));
 
 static void runKonfUpdate()
 {
-    KToolInvocation::kdeinitExecWait(QStringLiteral(KCONF_UPDATE_EXE),
-            QStringList(), nullptr, nullptr, "0" /*no startup notification*/);
+    QProcess kconfUpdate;
+    kconfUpdate.start(QStringLiteral(KCONF_UPDATE_EXE));
+    kconfUpdate.waitForFinished();
 }
 
 Kded::Kded()
@@ -152,8 +142,13 @@ QVector<KPluginMetaData> Kded::availableModules() const
     for (const KPluginMetaData &md : qAsConst(plugins)) {
         moduleIds.insert(md.pluginId());
     }
+#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 0)
     // also search for old .desktop based kded modules
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
+QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
     const KPluginInfo::List oldStylePlugins = KPluginInfo::fromServices(KServiceTypeTrader::self()->query(QStringLiteral("KDEDModule")));
+QT_WARNING_POP
     for (const KPluginInfo &info : oldStylePlugins) {
         if (moduleIds.contains(info.pluginName())) {
             qCWarning(KDED).nospace() << "kded module " << info.pluginName() << " has already been found using "
@@ -164,6 +159,7 @@ QVector<KPluginMetaData> Kded::availableModules() const
             plugins.append(info.toMetaData());
         }
     }
+#endif
     return plugins;
 }
 
@@ -173,13 +169,19 @@ static KPluginMetaData findModule(const QString &id)
     if (module.isValid()) {
         return module;
     }
+#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 0)
     // TODO KF6: remove the .desktop fallback code
     KService::Ptr oldStyleModule = KService::serviceByDesktopPath(QStringLiteral("kded/") + id + QStringLiteral(".desktop"));
     if (oldStyleModule) {
         qCDebug(KDED).nospace() << "kded module " << oldStyleModule->desktopEntryName()
             << " still uses .desktop files (" << oldStyleModule->entryPath() << "). Please port it to JSON metadata.";
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
+QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
         return KPluginInfo(oldStyleModule).toMetaData();
+QT_WARNING_POP
     }
+#endif
     qCWarning(KDED) << "could not find kded module with id" << id;
     return KPluginMetaData();
 }
@@ -211,12 +213,6 @@ void Kded::initModules()
         }
     }
 
-    // There will be a "phase 2" only if we're in the KDE startup.
-    // If kded is restarted by its crashhandled or by hand,
-    // then there will be no second phase autoload, so load
-    // these modules now, if in a KDE session.
-    const bool loadPhase2Now = (kde_running && qEnvironmentVariableIntValue("KDED_STARTED_BY_KDEINIT") == 0);
-
     // Preload kded modules.
     const QVector<KPluginMetaData> kdedModules = availableModules();
     for (const KPluginMetaData &module : kdedModules) {
@@ -238,7 +234,7 @@ void Kded::initModules()
             break;
         case 2: // autoload delayed, only in KDE
         default:
-            if (!loadPhase2Now) {
+            if (!kde_running) {
                 prevent_autoload = true;
             }
             break;
@@ -267,16 +263,7 @@ void Kded::initModules()
 
 void Kded::loadSecondPhase()
 {
-    qCDebug(KDED) << "Loading second phase autoload";
-    KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    const QVector<KPluginMetaData> kdedModules = availableModules();
-    for (const KPluginMetaData &module : kdedModules) {
-        const bool autoload = isModuleAutoloaded(module);
-        if (autoload && phaseForModule(module) == 2) {
-            qCDebug(KDED) << "2nd phase: loading" << module.pluginId();
-            loadModule(module, false);
-        }
-    }
+    qCDebug(KDED) << "Second phase autoload is deprecated";
 }
 
 void Kded::noDemandLoad(const QString &obj)
@@ -740,6 +727,9 @@ int main(int argc, char *argv[])
     // testing for --check, in which case, only a QCoreApplication was created.
     // Since that option is no longer used at startup, we removed that speed
     // optimization for code clarity and easier support of standard parameters.
+    
+    // Fixes blurry icons with Fractional scaling
+    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication app(argc, argv);
     if (unsetQpa) {
         qunsetenv("QT_QPA_PLATFORM");
